"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createKeyframes = exports.endHideAnimation = exports.setHideScrollAnimation = exports.setHideObserveAnimation = exports.endShowAnimation = exports.setShowScrollAnimation = exports.setShowObserveAnimation = exports.makeTimeToMillisecondString = exports.getAnimationType = exports.findDivByRef = exports.generateHashStringByLength = void 0;
var react_dom_1 = __importDefault(require("react-dom"));
var make_keyframes_1 = __importDefault(require("./animations/make.keyframes"));
var constants_1 = require("./constants");
function generateHashStringByLength(length) {
    if (length === void 0) { length = 6; }
    var result = [];
    var charactersLength = constants_1.characters.length;
    for (var i = 0; i < length; i++) {
        result.push(constants_1.characters.charAt(Math.floor(Math.random() * charactersLength)));
    }
    return result.join('');
}
exports.generateHashStringByLength = generateHashStringByLength;
function findDivByRef(element) {
    return react_dom_1.default.findDOMNode(element);
}
exports.findDivByRef = findDivByRef;
function getAnimationType(path) {
    return constants_1.animations[path];
}
exports.getAnimationType = getAnimationType;
var makeTimeToMillisecondString = function (number) { return number + "ms"; };
exports.makeTimeToMillisecondString = makeTimeToMillisecondString;
function setShowObserveAnimation(element, duration, delay) {
    element.style.transitionProperty = 'opacity transform';
    element.style.transitionDuration = exports.makeTimeToMillisecondString(duration);
    element.style.transitionDelay = exports.makeTimeToMillisecondString(delay);
    element.style.opacity = '1';
    element.style.transform = "translate3d(0, 0, 0)";
}
exports.setShowObserveAnimation = setShowObserveAnimation;
function setShowScrollAnimation(element, duration, delay, path) {
    element.style.animationDuration = exports.makeTimeToMillisecondString(duration);
    element.style.animationDelay = exports.makeTimeToMillisecondString(delay);
    element.style.animationName = getAnimationType(path);
}
exports.setShowScrollAnimation = setShowScrollAnimation;
var endShowAnimation = function (element, duration) {
    element.style.opacity = '1';
    setTimeout(function () {
        element.style.animation = 'none';
    }, duration);
};
exports.endShowAnimation = endShowAnimation;
function setHideObserveAnimation(element, duration, delay, offset) {
    element.style.transitionProperty = 'opacity transform';
    element.style.transitionDuration = exports.makeTimeToMillisecondString(duration / 5);
    element.style.transitionDelay = exports.makeTimeToMillisecondString(delay);
    element.style.opacity = '0';
    element.style.transform = "translate3d(" + (offset.x ? -offset.x : 0) + "px, " + (offset.y ? -offset.y : 0) + "px, " + (offset.z ? -offset.z : 0) + "px)";
}
exports.setHideObserveAnimation = setHideObserveAnimation;
function setHideScrollAnimation(element, duration, delay, path) {
    element.style.animationDuration = exports.makeTimeToMillisecondString(duration / 3);
    element.style.animationDelay = exports.makeTimeToMillisecondString(delay);
    element.style.animationName = getAnimationType(path);
    element.style.animationDirection = 'reverse';
}
exports.setHideScrollAnimation = setHideScrollAnimation;
var endHideAnimation = function (element, duration) {
    element.style.opacity = '0';
    setTimeout(function () {
        element.style.animation = 'none';
    }, duration / 3);
};
exports.endHideAnimation = endHideAnimation;
var isCreated = false;
function createKeyframes() {
    if (!isCreated)
        isCreated = true;
    else
        return;
    var style = document.createElement('style');
    style.type = 'text/css';
    var keyFrames = make_keyframes_1.default();
    style.innerHTML = keyFrames;
    document.getElementsByTagName('head')[0].appendChild(style);
}
exports.createKeyframes = createKeyframes;
//# sourceMappingURL=functions.js.map